[vlc-devel] [PATCH v3 01/14] libvlc: rename libvlc_video_direct3d_engine_d3d11

Steve Lhomme robux4 at ycbcr.xyz
Thu Feb 13 16:44:42 CET 2020


Use a similar name to the OpenGL engines
---
 doc/libvlc/d3d11_player.cpp       | 2 +-
 include/vlc/libvlc_media_player.h | 8 ++++----
 lib/media_player.c                | 2 +-
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/doc/libvlc/d3d11_player.cpp b/doc/libvlc/d3d11_player.cpp
index 946cfdb3237..70b947050e3 100644
--- a/doc/libvlc/d3d11_player.cpp
+++ b/doc/libvlc/d3d11_player.cpp
@@ -581,7 +581,7 @@ int WINAPI WinMain(HINSTANCE hInstance,
     // DON'T use with callbacks libvlc_media_player_set_hwnd(p_mp, hWnd);
 
     /* Tell VLC to render into our D3D11 environment */
-    libvlc_video_set_output_callbacks( p_mp, libvlc_video_direct3d_engine_d3d11,
+    libvlc_video_set_output_callbacks( p_mp, libvlc_video_engine_d3d11,
                                        Setup_cb, Cleanup_cb, Resize_cb, UpdateOutput_cb, Swap_cb, StartRendering_cb,
                                        nullptr, nullptr, SelectPlane_cb,
                                        &Context );
diff --git a/lib/media_player.c b/lib/media_player.c
index 4da37c13c8a..fdb56c1c362 100644
--- a/lib/media_player.c
+++ b/lib/media_player.c
@@ -1062,7 +1062,7 @@ bool libvlc_video_set_output_callbacks(libvlc_media_player_t *mp,
         var_SetString ( mp, "vout", "gl" );
         var_SetString ( mp, "gl", "vgl");
     }
-    else if ( engine == libvlc_video_direct3d_engine_d3d11 )
+    else if ( engine == libvlc_video_engine_d3d11 )
     {
         var_SetString ( mp, "vout", "direct3d11" );
         var_SetString ( mp, "dec-dev", "d3d11-device" );
diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index d93837d50ec..c4fb50e83de 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -538,7 +538,7 @@ typedef struct
  * A reference to this object is held until the \ref LIBVLC_VIDEO_DEVICE_CLEANUP is called.
  * the device must be created with D3DPRESENT_PARAMETERS.hDeviceWindow set to 0.
  *
  * For \ref libvlc_video_direct3d_engine_d3d11 the output must be a ID3D11DeviceContext*.
  * A reference to this object is held until the \ref LIBVLC_VIDEO_DEVICE_CLEANUP is called.
  * The ID3D11Device used to create ID3D11DeviceContext must have multithreading enabled.
  */
@@ -570,7 +570,7 @@ typedef struct
 typedef struct
 {
     union {
-        int dxgi_format;  /** the rendering DXGI_FORMAT for \ref libvlc_video_direct3d_engine_d3d11*/
+        int dxgi_format;  /** the rendering DXGI_FORMAT for \ref libvlc_video_engine_d3d11*/
         uint32_t d3d9_format;  /** the rendering D3DFORMAT for \ref libvlc_video_direct3d_engine_d3d9 */
         int opengl_format;  /** the rendering GLint GL_RGBA or GL_RGB for \ref libvlc_video_engine_opengl and
                             for \ref libvlc_video_engine_gles2 */
@@ -682,7 +682,7 @@ typedef enum libvlc_video_engine_t {
     libvlc_video_engine_opengl,
     libvlc_video_engine_gles2,
     /** Direct3D11 rendering engine */
-    libvlc_video_direct3d_engine_d3d11,
+    libvlc_video_engine_d3d11,
     /** Direct3D9 rendering engine */
     libvlc_video_direct3d_engine_d3d9,
 } libvlc_video_engine_t;
@@ -711,7 +711,7 @@ typedef void( *libvlc_video_output_set_resize_cb )( void *opaque,
  * \return true on success
  * \version LibVLC 4.0.0 or later
  *
  * \note This is only used with \ref libvlc_video_direct3d_engine_d3d11.
  *
  * The host should call OMSetRenderTargets for Direct3D11. If this callback is
  * not used (set to NULL in @a libvlc_video_set_output_callbacks()) OMSetRenderTargets
@@ -538,7 +538,7 @@ typedef struct
  * the device must be created with D3DPRESENT_PARAMETERS.hDeviceWindow set to 0.
  *
- * For \ref libvlc_video_direct3d_engine_d3d11 the output must be a ID3D11DeviceContext*.
+ * For \ref libvlc_video_engine_d3d11 the output must be a ID3D11DeviceContext*.
  * A reference to this object is held until the \ref LIBVLC_VIDEO_DEVICE_CLEANUP is called.
  * The ID3D11Device used to create ID3D11DeviceContext must have multithreading enabled.
@@ -711,7 +711,7 @@ typedef void( *libvlc_video_output_set_resize_cb )( void *opaque,
  * \version LibVLC 4.0.0 or later
  *
- * \note This is only used with \ref libvlc_video_direct3d_engine_d3d11.
+ * \note This is only used with \ref libvlc_video_engine_d3d11.
  *
  * The host should call OMSetRenderTargets for Direct3D11. If this callback is
-- 
2.17.1



More information about the vlc-devel mailing list